# Cat-And-Rat-Gym-Environment

An OpenAI gym compatible environment for training RL algorithms.

The Game: a cat and a rat are placed in a toroidal playing feild of arbitrary size. Using RK4 dynamics simulation, the cat "chases" the rat around. The rat's goal is to evade the cat for a fixed duration, while the cat's goal is to catch the rat before time runs out. This v-0 environment has the rat preforming an random walk, and the cat being AI controlled.

Written by Callum Welsh and Connor Fieweger for the Chin Group at the University of Chicago
